@@ -17,8 +17,14 @@ def watrem(data, dt, n, f):
     dwell = dt
     nsv_sought = n
     result = hlsvdpro.hlsvd(data, nsv_sought, dwell)
-    nsv_found, singvals, freq, damp, ampl, phas = result
-    idx = np.where((f[0] < result[2]) & (result[2] < f[1]))
+    # nsv_found, singvals, freq, damp, ampl, phas = result
+    min_band = f[0]
+    max_band = f[1]
+    idx = []
+    for min_, max_ in zip(min_band,max_band):
+        idx.append(np.where(((result[2]) > min_) & ((result[2]) < max_)))
+    idx = np.unique(np.concatenate(idx, 1))
+    # idx = np.where((f[0] < result[2]) & (result[2] < f[1]))
     result = (len(idx), result[1], result[2][idx], result[3][idx], result[4][idx], result[5][idx])
     fid = hlsvdpro.create_hlsvd_fids(result, npts, dwell, sum_results=True, convert=False)
     return data - fid
